@@ -2,10 +2,12 @@ import json
 import logging
 import re
 import urllib.parse
+from urllib.parse import urlparse
 
 import requests
 from levo_commons.models import Interaction
 from levo_commons.status import Status
+from requests.structures import CaseInsensitiveDict
 
 
 class Requester(object):
@@ -13,7 +15,7 @@ class Requester(object):
     host = ""
     method = ""
     action = ""
-    headers: dict[str, str] = {}
+    headers: CaseInsensitiveDict = CaseInsensitiveDict()
     data: dict[str, str] = {}
     interactions: list[Interaction] = []
 
@@ -27,13 +29,19 @@ class Requester(object):
             exit()
 
         try:
-            content = content.split("\n")
-            # Parse method and action URI
-            regex = re.compile("(.*) (.*) HTTP")
-            self.method, self.action = regex.findall(content[0])[0]
+            content = content.split("\n\n", 1)
+            request_line = content[0].split("\n", 1)[0]
+            headers = content[0].split("\n")[1:]
+            body = content[1] if len(content) == 2 else None
 
-            # Parse headers
-            for header in content[1:]:
+            regex = re.compile("(.*) (.*) HTTP")
+            self.method, self.action = regex.findall(request_line)[0]
+            url = urlparse(self.action)
+            if url.path != self.action:
+                self.action = url.path
+                self.headers["Host"] = url.netloc
+
+            for header in headers:
                 name, _, value = header.partition(": ")
                 if not name or not value:
                     continue
@@ -41,20 +49,24 @@ class Requester(object):
             self.host = self.headers["Host"]
 
             # Parse user-agent
-            if uagent != None:
+            if uagent is not None:
                 self.headers["User-Agent"] = uagent
 
             # Parse data
-            self.data_to_dict(content[-1])
+            self.data_to_dict(body)
 
             # Handling HTTPS requests
-            if ssl == True:
+            if ssl:
                 self.protocol = "https"
 
         except Exception as e:
-            logging.warning("Bad Format or Raw data !")
+            logging.warning(f"Bad Format or Raw data: {e}")
+            exit()
 
     def data_to_dict(self, data):
+        if data is None:
+            return {}
+
         if self.method == "POST":
 
             # Handle JSON data
@@ -145,7 +157,8 @@ class Requester(object):
                     verify=False,
                 )
         except Exception as e:
-            return None
+            logging.error(e)
+            exit()
         self.interactions.append(
             Interaction.from_requests(
                 r, Status.success if 200 <= r.status_code <= 299 else Status.error, []
